==> kdepim-4.2.4.tar.xz: kdepim-4.2.4/kleopatra/models/keycache_p.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    models/keycache_p.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_KEYCACHE_P_H__
#define __KLEOPATRA_KEYCACHE_P_H__

#include "keycache.h"
#include <utils/pimpl_ptr.h>

namespace GpgME {
    class KeyListResult;
}

namespace Kleo {

    class KeyCache::RefreshKeysJob : public QObject {
        Q_OBJECT
    public:

        explicit RefreshKeysJob( KeyCache* cache, QObject* parent = 0 );
        ~RefreshKeysJob();

        void start();
        void cancel();

   Q_SIGNALS:
        void done( const GpgME::KeyListResult & );
        void canceled();

    private:
        class Private;
        friend class Private;
        kdtools::pimpl_ptr<Private> d;
        Q_PRIVATE_SLOT( d, void jobDone( GpgME::KeyListResult ) )
        Q_PRIVATE_SLOT( d, void nextSecretKey( GpgME::Key ) )
        Q_PRIVATE_SLOT( d, void nextPublicKey( GpgME::Key ) )
        Q_PRIVATE_SLOT( d, void doStart() )
    };
}

#endif // __KLEOPATRA_KEYCACHE_P_H__

==> kdepim-4.8.90.tar.xz: kdepim-4.8.90/kleopatra/models/keycache_p.h <==
/* -*- mode: c++; c-basic-offset:4 -*-
    models/keycache_p.h

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#ifndef __KLEOPATRA_KEYCACHE_P_H__
#define __KLEOPATRA_KEYCACHE_P_H__

#include "keycache.h"
#include <utils/pimpl_ptr.h>

namespace GpgME {
    class KeyListResult;
}

namespace Kleo {

    class KeyCache::RefreshKeysJob : public QObject {
        Q_OBJECT
    public:

        explicit RefreshKeysJob( KeyCache* cache, QObject* parent = 0 );
        ~RefreshKeysJob();

        void start();
        void cancel();

   Q_SIGNALS:
        void done( const GpgME::KeyListResult & );
        void canceled();

    private:
        class Private;
        friend class Private;
        kdtools::pimpl_ptr<Private> d;
        Q_PRIVATE_SLOT( d, void listAllKeysJobDone(GpgME::KeyListResult, std::vector<GpgME::Key>) )
        Q_PRIVATE_SLOT( d, void doStart() )
    };
}

#endif // __KLEOPATRA_KEYCACHE_P_H__
